@@ -19,6 +19,7 @@
 #include <math.h>
 
 #include <qpainter.h>
+#include <qcursor.h>
 
 #include <klocale.h>
 #include <kglobal.h>
@@ -41,9 +42,6 @@ EyesApplet::EyesApplet(const QString& configFile, Type t, int actions,
                        QWidget *parent, const char *name)
   : KPanelApplet( configFile, t, actions, parent, name )
 {
-    display = kapp->getDisplay();
-    root = RootWindow(display,DefaultScreen(display));
-
     startTimer(41); // 24 frames/second ;-)
 }
 
@@ -97,20 +95,16 @@ void EyesApplet::drawPupils(QPainter* p)
 {
     QPoint pos, mouse, vect;
     double cos_alpha,sin_alpha;
-    int WinX, WinY;
-    int XCoord,YCoord;
 
-    // query global cursor position
-    XQueryPointer (display, root, &RootIDRet, &ChildIDRet, &XCoord,&YCoord, &WinX, &WinY, &StateMask);
-    mouse = mapFromGlobal(QPoint(XCoord,YCoord));
+    mouse = mapFromGlobal(QCursor::pos());
     int tmp = QMIN(height(),width())/6;
 
     // left pupil
     vect.setX(mouse.x() - width()/4);
     vect.setY(mouse.y() - height()/2);
 
-    cos_alpha = vect.x() / sqrt(vect.x() * vect.x() + vect.y() * vect.y());
-    sin_alpha = vect.y() / sqrt(vect.x() * vect.x() + vect.y() * vect.y());
+    cos_alpha = vect.x() / sqrt(double(vect.x() * vect.x() + vect.y() * vect.y()));
+    sin_alpha = vect.y() / sqrt(double(vect.x() * vect.x() + vect.y() * vect.y()));
 
     if(vect.x() * vect.x() + vect.y() * vect.y() > (width()/4 - tmp) * (width()/4 - tmp)*
        cos_alpha * cos_alpha+ (height()/2-tmp) * (height()/2-tmp) * sin_alpha * sin_alpha) {
@@ -141,8 +135,8 @@ void EyesApplet::drawPupils(QPainter* p)
     vect.setX(mouse.x() - 3*width()/4);
     vect.setY(mouse.y() - height()/2);
 
-    cos_alpha = vect.x()/sqrt(vect.x()*vect.x()+vect.y()*vect.y());
-    sin_alpha = vect.y()/sqrt(vect.x()*vect.x()+vect.y()*vect.y());
+    cos_alpha = vect.x()/sqrt(double(vect.x()*vect.x()+vect.y()*vect.y()));
+    sin_alpha = vect.y()/sqrt(double(vect.x()*vect.x()+vect.y()*vect.y()));
 
     if(vect.x()*vect.x() + vect.y()*vect.y() > (width()/4-tmp)*(width()/4-tmp)
        *cos_alpha*cos_alpha+(height()/2-tmp)*(height()/2-tmp)*sin_alpha*sin_alpha)
