@@ -28,25 +28,28 @@ class MoonWidget;
 class QPushButton;
 
 class KMoonDlg : public KDialogBase {
-    Q_OBJECT
-
-public:
-    KMoonDlg(int angle, bool north, QWidget *parent, const char *name);
-    int getAngle() const { return angle; }
-    bool northHemi() const { return north; }
-
-private:
-    QSlider *slider;
-    MoonWidget *moon;
-    int angle;
-    bool north;
-    QPushButton *hemitoggle;
-
+  Q_OBJECT
+    
+ public:
+  KMoonDlg(int angle, bool north, bool mask, QWidget *parent, const char *name);
+  int getAngle() const { return angle; }
+  bool getNorthHemi() const { return north; }
+  bool getMask() const { return mask; }
+  
+ private:
+  QSlider *slider;
+  MoonWidget *moon;
+  int angle;
+  bool north;
+  bool mask;
+  QPushButton *hemitoggle;
+  QPushButton *masktoggle;
+  
  private slots:
-    void valueChanged(int);
-    void help();
-    void toggleHemi();
-
+  void help();
+  void angleChanged(int);
+  void toggleHemi();
+  void toggleMask();
 };
 
 #endif
