@@ -1,25 +1,25 @@
-/*                                                                      
-    This file is part of KWeather.                                  
+/*
+    This file is part of KWeather.
     Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-                                                                        
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or   
-    (at your option) any later version.                                 
-                                                                        
-    This program is distributed in the hope that it will be useful,     
-    but WITHOUT ANY WARRANTY; without even the implied warranty of      
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the        
-    GNU General Public License for more details.                        
-                                                                        
-    You should have received a copy of the GNU General Public License   
-    along with this program; if not, write to the Free Software         
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           
-                                                                        
-    As a special exception, permission is given to link this program    
-    with any edition of Qt, and distribute the resulting executable,    
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
+    As a special exception, permission is given to link this program
+    with any edition of Qt, and distribute the resulting executable,
     without including the source code for Qt in the source distribution.
-*/                                                                      
+*/
 
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
@@ -43,7 +43,7 @@ extern "C"
 {
   KCModule *create_weather( QWidget *parent, const char * )
   {
-    return new KCMWeather( parent, "kcmweather" );
+    return new KCMWeather( parent, "kweather" );
   }
 }
 
@@ -52,11 +52,16 @@ KCMWeather::KCMWeather( QWidget *parent, const char *name )
 {
   QVBoxLayout *layout = new QVBoxLayout( this );
   mWidget = new prefsDialogData( this );
+
+  // set the focus to the text entry instead of the config module page selection.
+  // note that this dialog is only created once, so this only happens one time.
+  mWidget->m_reportLocation->setFocus();
+
   layout->addWidget( mWidget );
 
 	connect( mWidget->ICAOlink, SIGNAL( leftClickedURL( const QString& ) ),
            SLOT( processURL( const QString& ) ) );
-	connect( mWidget->m_enableLog, SIGNAL( toggled( bool ) ), 
+	connect( mWidget->m_enableLog, SIGNAL( toggled( bool ) ),
            SLOT( enableLogWidgets( bool ) ) );
 	connect( mWidget->m_viewMode, SIGNAL( released( int ) ),
            SLOT( changeViewMode( int ) ) );
@@ -98,7 +103,7 @@ void KCMWeather::load()
   enableLogWidgets( enabled );
 
   mWidget->m_logFile->setURL( config.readPathEntry( "log_file_name" ) );
-  mWidget->m_reportLocation->setText( config.readEntry( "report_location", i18n( "none" ) ) );
+  mWidget->m_reportLocation->setText( config.readEntry( "report_location" ) );
   mWidget->m_viewMode->setButton( config.readNumEntry( "smallview_mode", dockwidget::ShowAll ) );
   changeViewMode( config.readNumEntry( "smallview_mode", dockwidget::ShowAll ) );
   emit changed( false );
@@ -124,7 +129,7 @@ void KCMWeather::defaults()
   enableLogWidgets( false );
 
   mWidget->m_logFile->setURL( "" );
-  mWidget->m_reportLocation->setText( i18n( "none" ) );
+  mWidget->m_reportLocation->setText( "" );
   changeViewMode( dockwidget::ShowAll );
 
   emit changed( true );
