@@ -1,4 +1,4 @@
-/* $Id: weatherservice.cpp,v 1.30 2004/01/10 11:57:39 mueller Exp $ */
+/* $Id: weatherservice.cpp,v 1.38 2004/06/07 00:04:03 jratke Exp $ */
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -11,24 +11,19 @@
 #include "stationdatabase.h"
 #include "sun.h"
 
-WeatherService::WeatherService() : QObject (0,"WeatherService"),  DCOPObject("WeatherService")
+WeatherService::WeatherService(QObject *parent, const char *name) : QObject (parent, name),  DCOPObject("WeatherService")
 {
 	kdDebug(12006) << "Starting new service... " << endl;
 
 	stationDB = new StationDatabase();
-	if ( !stationDB->loadDatabase() )
-	{
-		delete stationDB;
-		stationDB = 0L;
-	}
 
-	m_weatherLib = new WeatherLib(stationDB);
+	m_weatherLib = new WeatherLib(stationDB, this, "WeatherLib");
 	connect(m_weatherLib, SIGNAL(fileUpdating( const QString&)),
 			SLOT(updating( const QString&)));
 	connect(m_weatherLib, SIGNAL(fileUpdate( const QString&)),
 			SLOT(updated( const QString&)));
-  connect(m_weatherLib, SIGNAL(stationRemoved(const QString&)),
-      SLOT(slotStationRemoved(const QString&)));
+	connect(m_weatherLib, SIGNAL(stationRemoved(const QString&)),
+			SLOT(slotStationRemoved(const QString&)));
 
 	KConfig *conf = kapp->config();
 
@@ -41,7 +36,10 @@ WeatherService::WeatherService() : QObject (0,"WeatherService"),  DCOPObject("We
 WeatherService::~WeatherService()
 {
 	kdDebug(12006) << "Going away... " << endl;
-	saveSettings();
+	// Don't need to call saveSettings() because WeatherService::exit already does that.
+	// Plus it wouldn't work here anyway because we can't get the config after calling
+	// kapp->quit();
+	delete stationDB;
 }
 
 void WeatherService::updated(const QString &stationID)
@@ -152,6 +150,12 @@ QStringList WeatherService::weather(const QString &stationID)
 {
 	return m_weatherLib->weather(stationID);
 }
+
+bool WeatherService::stationNeedsMaintenance(const QString &stationID)
+{
+	return m_weatherLib->stationNeedsMaintenance(stationID);
+}
+
 void WeatherService::update(const QString &stationID)
 {
 	m_weatherLib->update(stationID);
@@ -196,7 +200,10 @@ void WeatherService::saveSettings()
 QString WeatherService::stationName(const QString &stationID)
 {
 	if ( stationDB )
-		return stationDB->stationNameFromID(stationID);
+	{
+		QString upperStationID = stationID.upper();
+		return stationDB->stationNameFromID(upperStationID);
+	}
 	else
 		return stationID;
 }
@@ -204,21 +211,30 @@ QString WeatherService::stationCountry(const QString &stationID)
 {
 
 	if ( stationDB )
-		return stationDB->stationCountryFromID(stationID);
+	{
+		QString upperStationID = stationID.upper();
+		return stationDB->stationCountryFromID(upperStationID);
+	}
 	else
 		return stationID;
 }
 QString WeatherService::longitude(const QString &stationID)
 {
 	if ( stationDB )
-		return stationDB->stationLongitudeFromID(stationID);
+	{
+		QString upperStationID = stationID.upper();
+		return stationDB->stationLongitudeFromID(upperStationID);
+	}
 	else
 		return "None";
 }
 QString WeatherService::latitude(const QString &stationID)
 {
 	if ( stationDB )
-		return stationDB->stationLatitudeFromID(stationID);
+	{
+		QString upperStationID = stationID.upper();
+		return stationDB->stationLatitudeFromID(upperStationID);
+	}
 	else
 		return "None";
 }
@@ -230,33 +246,66 @@ QStringList WeatherService::findStations(float lon, float lat)
 	return stationList;
 }
 
+QString WeatherService::getTime(const QString &stationID, TimeType timeType)
+{
+	QString upperStationID = stationID.upper();
+
+	QString latitude  = stationDB->stationLatitudeFromID(upperStationID);
+	QString longitude = stationDB->stationLongitudeFromID(upperStationID);
+
+	if ( latitude.compare(  i18n("Unknown Station" ) ) == 0  ||
+	     longitude.compare( i18n("Unknown Station" ) ) == 0 )
+	{
+		return i18n( "Unknown Station" );
+	}
+	else
+	{
+		Sun theSun( latitude, longitude );
+		
+		QTime time;
+		switch ( timeType )
+		{
+			case RISE:
+				time = theSun.computeRiseTime();
+				break;
+			case SET:
+				time = theSun.computeSetTime();
+				break;
+			case CIVIL_START:
+				time = theSun.computeCivilTwilightStart();
+				break;
+			case CIVIL_END:
+				time = theSun.computeCivilTwilightEnd();
+				break;
+		}
+
+		kdDebug(12006) << "station, lat, lon, time: " << upperStationID << " " <<
+			latitude << " " << longitude << " " << time << endl;
+
+		return KGlobal::locale()->formatTime(time);
+	}
+}
+
 QString WeatherService::sunRiseTime(const QString &stationID)
 {
-	Sun thesun;
-
-	QString latitude  = stationDB->stationLatitudeFromID(stationID);
-	QString longitude = stationDB->stationLongitudeFromID(stationID);
-
-	QTime   rise_time = thesun.computeRiseTime(latitude, longitude);
-
-	kdDebug(12006) << "rise time: " << rise_time << endl;
-
-	return KGlobal::locale()->formatTime(rise_time);
+	return getTime(stationID, RISE);
 }
 
 QString WeatherService::sunSetTime(const QString &stationID)
 {
-	Sun thesun;
+	return getTime(stationID, SET);
+}
 
-	QString latitude  = stationDB->stationLatitudeFromID(stationID);
-	QString longitude = stationDB->stationLongitudeFromID(stationID);
+QString WeatherService::civilTwilightStart(const QString &stationID)
+{
+	return getTime(stationID, CIVIL_START);
+}
 
-	QTime   set_time  = thesun.computeSetTime(latitude, longitude);
-
-	kdDebug(12006) << "set time: " << set_time << endl;
-
-	return KGlobal::locale()->formatTime(set_time);
+QString WeatherService::civilTwilightEnd(const QString &stationID)
+{
+	return getTime(stationID, CIVIL_END);
 }
 
 
+
 #include "weatherservice.moc"
