@@ -67,6 +67,7 @@ public:
   void setIllumination(bool i);
   void setCities(bool c);
   void setFlags(bool f);
+  void setSize(int w, int h);
 
   void save(KConfig *config);
   void load(KConfig *config);
@@ -76,6 +77,9 @@ public:
   QPixmap getPixmap();
   QPopupMenu* contextMenu() { return _popup; }
 
+  void paintContents(QPainter *p);
+  QPixmap calculatePixmap();
+
 signals:
 
   void addClockClicked(QString zone);
@@ -110,8 +114,6 @@ protected:
   void enterEvent(QEvent *ev);
   void leaveEvent(QEvent *ev);
 
-  QPixmap calculatePixmap();
-
 
 private slots:
 
@@ -151,6 +153,8 @@ private:
 
   bool _applet;
   QTimer m_timer;
+  
+  int _width, _height;
 };
 
 
