@@ -1,4 +1,30 @@
+/*
+**
+** Copyright (C) 1998-2001 by Matthias Hlzer-Klpfel <hoelzer@kde.org>
+**	Maintainence has ceased - send questions to kde-devel@kde.org.
+**
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #include "config.h"
 
 #include <stdlib.h>
@@ -23,18 +49,16 @@
 #include "clock.h"
 #include "cities.h"
 #include "zoneclock.moc"
+#include <kdebug.h>
 
-
-ZoneClock::ZoneClock(QString zone, QString name, QWidget *parent, const char *n)
+ZoneClock::ZoneClock(const QString &zone, const QString &name, QWidget *parent, const char *n)
   : QFrame(parent, n), _zone(zone), _name(name)
 {
   setFrameStyle(QFrame::Panel | QFrame::Raised);
-
   QHBoxLayout *hbox = new QHBoxLayout(this, 2,2);
-  
-//  _name.append(":");
-  _nameLabel = new QLabel(_name.append(":"), this);
-//  _nameLabel = new QLabel(i18n(_zone.utf8()).section('/', -1).append(":"), this);
+
+  _name.append(":");
+  _nameLabel = new QLabel(_name, this);
   hbox->addWidget(_nameLabel, 1);
   hbox->addSpacing(4);
 
@@ -95,13 +119,12 @@ void ZoneClock::editClock()
   if (_dlg->exec() == QDialog::Accepted)
     {
       _zone = timezones[_dlg->ClockZone->currentItem()];
-      _name = _zone.section('/', -1).append(":");
+      _name = _dlg->ClockCaption->text().append(":");
       _nameLabel->setText(_dlg->ClockCaption->text().append(":"));
-// _dlg->ClockZone->currentText().append(":"));
       updateTime();
       layout()->invalidate();
       emit changed();
-    }  
+    }
 
   delete _dlg;
 }
@@ -113,11 +136,11 @@ bool ZoneClock::eventFilter(QObject *obj, QEvent *ev)
     {
       QMouseEvent *e = (QMouseEvent*)ev;
       if (e->button() == QMouseEvent::RightButton)
-	_popup->exec(e->globalPos());      
+	_popup->exec(e->globalPos());
     }
 
   return QFrame::eventFilter(obj, ev);
-} 
+}
 
 
 void ZoneClock::updateTime()
@@ -125,13 +148,16 @@ void ZoneClock::updateTime()
   char *initial_TZ = getenv("TZ");
   setenv("TZ", _zone.latin1(), 1);
   tzset();
- 
+
   time_t t = time(NULL);
   QDateTime dt;
   dt.setTime_t(t);
   _timeLabel->setText(QString("%1, %2").arg(KGlobal::locale()->formatTime(dt.time(), true)).arg(KGlobal::locale()->formatDate(dt.date(), true)));
- 
-  if (initial_TZ != 0) setenv("TZ", initial_TZ, 1);
+
+  if (initial_TZ != 0)
+    setenv("TZ", initial_TZ, 1);
+  else
+    unsetenv("TZ");
   tzset();
 }
 
@@ -163,14 +189,14 @@ void ZoneClockPanel::createDialog()
 }
 
 
-void ZoneClockPanel::addClock(QString zone, QString name)
+void ZoneClockPanel::addClock(const QString &zone, const QString &name)
 {
   // add the clocks
   ZoneClock *zc = new ZoneClock(zone, name, this);
   _flow->add(zc);
   _clocks.append(zc);
   zc->show();
- 
+
   realign();
 
   connect(zc, SIGNAL(addClock(QString)), this, SLOT(addClock(QString)));
@@ -207,7 +233,6 @@ void ZoneClockPanel::updateTimer()
     it.current()->updateTime();
 }
 
-
 void ZoneClockPanel::addClock(QString zone)
 {
   createDialog();
@@ -234,7 +259,7 @@ void ZoneClockPanel::addClock(QString zone)
 void ZoneClockPanel::save(KConfig *config)
 {
   config->writeEntry("Clocks", _clocks.count());
- 
+
   QPtrListIterator<ZoneClock> it(_clocks);
   int cnt=0;
   for ( ; it.current(); ++it)
@@ -244,7 +269,7 @@ void ZoneClockPanel::save(KConfig *config)
       config->writeEntry(QString("Clock_%1_Name").arg(cnt), n);
       config->writeEntry(QString("Clock_%1_Zone").arg(cnt), it.current()->zone());
       cnt++;
-    }  
+    }
 }
 
 
@@ -253,10 +278,10 @@ void ZoneClockPanel::load(KConfig *config)
   _clocks.clear();
 
   int num = config->readNumEntry("Clocks", 0);
- 
+
   for (int i=0; i<num; ++i)
     {
       addClock(config->readEntry(QString("Clock_%1_Zone").arg(i)), config->readEntry(QString("Clock_%1_Name").arg(i)));
-    }  
+    }
 }
 
